@@ -1,22 +1,21 @@
 /*
- * Copyright (c) 1997, 1998, 1999, 2000, 2005
+ * Copyright (c) 1997, 1998, 1999, 2000, 2005, 2006
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
- * GNU GLOBAL is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * GNU GLOBAL is distributed in the hope that it will be useful,
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef _PATHOP_H_
@@ -28,24 +27,27 @@
 
 #define NEXTKEY		" __.NEXTKEY"
 
-/*
- * File type
+/**
+ * @name File type
  */
-#define GPATH_SOURCE	0
-#define GPATH_OTHER	1
+/** @{ */
+#define GPATH_SOURCE	1
+#define GPATH_OTHER	2
+#define GPATH_BOTH	3
+/** @} */
 
 typedef struct {
-	/* set by gfind_open() */
+	/** set by gfind_open() */
 	DBOP *dbop;
 	const char *prefix;
-	int other;
+	int target;
 	int version;
-	/* set by gfind_open() and gfind_read() */
+	/** set by gfind_open() and gfind_read() */
 	int first;
-	int eod;		/* end of data */
+	int eod;		/**< end of data */
 	/* set by gfind_read() */
-	int type;		/* File type */
-	const char *path;	/* return value of gfind_read() */
+	int type;		/**< File type; set by gfind_read() */
+	const char *path;	/**< return value of gfind_read() */
 } GFIND;
 
 int gpath_open(const char *, int);
