@@ -3,19 +3,18 @@
  *
  * This file is part of GNU GLOBAL.
  *
- * GNU GLOBAL is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * GNU GLOBAL is distributed in the hope that it will be useful,
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -24,21 +23,18 @@
 #include "die.h"
 #include "strlimcpy.h"
 
-/*
+/**
  * strlimcpy: copy string with limit.
  *
- *	o)	dest	destination string
- *	i)	source	source string
- *	i)	limit	size of dest
+ *	@param[out]	dest	destination string
+ *	@param[in]	source	source string
+ *	@param[in]	limit	size of @a dest
  *
- * NOTE: This function is similar to strlcpy of OpenBSD but is different
- * because strlimcpy abort when it beyond the limit.
+ * @note This function is similar to @NAME{strlcpy()} of @NAME{OpenBSD} but is different
+ * because @NAME{strlimcpy} abort when it beyond the limit.
  */
 void
-strlimcpy(dest, source, limit)
-	char *dest;
-	const char *const source;
-	const int limit;
+strlimcpy(char *dest, const char *const source, const int limit)
 {
 	int n = (int)limit;
 	const char *s = source;
